@@ -22,7 +22,7 @@ class Query(Query):
 echo = False
 
 
-engine = create_engine('', convert_unicode=True, echo=True)
+engine = create_engine('sqlite://', convert_unicode=True, echo=True)
 Session = sessionmaker(
     autoflush=False,
     expire_on_commit=False,
