@@ -1,5 +1,4 @@
 import datetime
-import itertools
 import logging
 
 from lxml import html
@@ -93,7 +92,6 @@ class Essays(object):
         for i in self: pass # Make sure that all essays names have been retrieved
         return self._short_name_to_title
 
-
     @util.cached_property
     def _essays(self):
         return self._essays_xpb.one_(self._profile_tree)
@@ -164,14 +162,13 @@ class QuestionFetcher(object):
 
     def fetch(self, start_at=0, get_at_least=None, id_to_existing=None):
         current_offset = start_at + 1
-        generators = []
         while True:
             tree = html.fromstring(self._html_fetcher.fetch(current_offset))
-            generators.append(self._processor.process(tree))
+            for i in self._processor.process(tree):
+                yield i
             if not self._pages_left(tree):
                 break
             current_offset = current_offset + self.step
-        return itertools.chain(*generators)
 
 
 class QuestionHTMLFetcher(object):
@@ -380,6 +377,11 @@ class Profile(object):
         self.refresh(reload=False)
         return return_value
 
+    @util.cached_property
+    def attractiveness(self):
+        from .attractiveness_finder import AttractivenessFinder
+        return AttractivenessFinder(self._session)(self.username)
+
     def rate(self, rating):
         parameters = {
             'voterid': self._current_user_id,
@@ -410,6 +412,8 @@ class Profile(object):
                                        'headers': dict(self._session.headers)}))
         self.refresh(reload=False)
 
+    def __eq__(self, other):
+        self.username.lower() == other.username.lower()
+
     def __repr__(self):
         return 'Profile("{0}")'.format(self.username)
-
